@@ -81,12 +81,10 @@ enum {
 static guint signals[LAST_SIGNAL];
 static GParamSpec *properties[N_PROPERTIES] = { NULL };
 
-typedef struct _LoaderInfo LoaderInfo;
-
-struct _LoaderInfo {
+typedef struct _LoaderInfo {
   PeasPluginLoader *loader;
   PeasObjectModule *module;
-};
+} LoaderInfo;
 
 typedef struct _SearchPath {
   gchar *module_dir;
@@ -264,7 +262,7 @@ peas_engine_insert_search_path (PeasEngine  *engine,
  * @module_dir.
  */
 void
-peas_engine_add_search_path (PeasEngine *engine,
+peas_engine_add_search_path (PeasEngine  *engine,
                              const gchar *module_dir,
                              const gchar *data_dir)
 {
@@ -281,9 +279,11 @@ peas_engine_add_search_path (PeasEngine *engine,
  * look for plugins.
  *
  * See Also: peas_engine_add_search_path()
+ *
+ * Since: 1.6
  */
 void
-peas_engine_prepend_search_path (PeasEngine *engine,
+peas_engine_prepend_search_path (PeasEngine  *engine,
                                  const gchar *module_dir,
                                  const gchar *data_dir)
 {
@@ -317,7 +317,13 @@ loader_destroy (LoaderInfo *info)
     return;
 
   if (info->loader)
-    g_object_unref (info->loader);
+    {
+      g_object_add_weak_pointer (G_OBJECT (info->loader),
+                                 (gpointer *) &info->loader);
+
+      g_object_unref (info->loader);
+      g_assert (info->loader == NULL);
+    }
 
   g_free (info);
 }
@@ -785,9 +791,9 @@ peas_engine_get_plugin_info (PeasEngine  *engine,
   return l == NULL ? NULL : (PeasPluginInfo *) l->data;
 }
 
-static gboolean
-load_plugin (PeasEngine     *engine,
-             PeasPluginInfo *info)
+static void
+peas_engine_load_plugin_real (PeasEngine     *engine,
+                              PeasPluginInfo *info)
 {
   const gchar **dependencies;
   PeasPluginInfo *dep_info;
@@ -795,10 +801,10 @@ load_plugin (PeasEngine     *engine,
   PeasPluginLoader *loader;
 
   if (peas_plugin_info_is_loaded (info))
-    return TRUE;
+    return;
 
   if (!peas_plugin_info_is_available (info, NULL))
-    return FALSE;
+    return;
 
   /* We set the plugin info as loaded before trying to load the dependencies,
    * to make sure we won't have an infinite loop. */
@@ -858,27 +864,19 @@ load_plugin (PeasEngine     *engine,
 
   g_debug ("Loaded plugin '%s'", peas_plugin_info_get_module_name (info));
 
-  return TRUE;
+  g_object_notify_by_pspec (G_OBJECT (engine),
+                            properties[PROP_LOADED_PLUGINS]);
+
+  return;
 
 error:
 
   info->loaded = FALSE;
   info->available = FALSE;
-
-  return FALSE;
-}
-
-static void
-peas_engine_load_plugin_real (PeasEngine     *engine,
-                              PeasPluginInfo *info)
-{
-  if (load_plugin (engine, info))
-    g_object_notify_by_pspec (G_OBJECT (engine),
-                              properties[PROP_LOADED_PLUGINS]);
 }
 
 /**
- * peas_engine_load_plugin:
+ * peas_engine_load_plugin: (virtual load_plugin)
  * @engine: A #PeasEngine.
  * @info: A #PeasPluginInfo.
  *
@@ -887,7 +885,6 @@ peas_engine_load_plugin_real (PeasEngine     *engine,
  * actually occurs in the default signal handler.
  *
  * Returns: whether the plugin has been successfully loaded.
- * Virtual: load_plugin
  */
 gboolean
 peas_engine_load_plugin (PeasEngine     *engine,
@@ -896,12 +893,12 @@ peas_engine_load_plugin (PeasEngine     *engine,
   g_return_val_if_fail (PEAS_IS_ENGINE (engine), FALSE);
   g_return_val_if_fail (info != NULL, FALSE);
 
-  if (!peas_plugin_info_is_available (info, NULL))
-    return FALSE;
-
   if (peas_plugin_info_is_loaded (info))
     return TRUE;
 
+  if (!peas_plugin_info_is_available (info, NULL))
+    return FALSE;
+
   g_signal_emit (engine, signals[LOAD_PLUGIN], 0, info);
 
   return peas_plugin_info_is_loaded (info);
@@ -915,8 +912,7 @@ peas_engine_unload_plugin_real (PeasEngine     *engine,
   const gchar *module_name;
   PeasPluginLoader *loader;
 
-  if (!peas_plugin_info_is_loaded (info) ||
-      !peas_plugin_info_is_available (info, NULL))
+  if (!peas_plugin_info_is_loaded (info))
     return;
 
   /* We set the plugin info as unloaded before trying to unload the
@@ -944,13 +940,16 @@ peas_engine_unload_plugin_real (PeasEngine     *engine,
 
   g_debug ("Unloaded plugin '%s'", peas_plugin_info_get_module_name (info));
 
+  /* Don't notify while in dispose so the
+   * loaded plugins can easily be kept in GSettings
+   */
   if (!engine->priv->in_dispose)
     g_object_notify_by_pspec (G_OBJECT (engine),
                               properties[PROP_LOADED_PLUGINS]);
 }
 
 /**
- * peas_engine_unload_plugin:
+ * peas_engine_unload_plugin: (virtual unload_plugin)
  * @engine: A #PeasEngine.
  * @info: A #PeasPluginInfo.
  *
@@ -959,7 +958,6 @@ peas_engine_unload_plugin_real (PeasEngine     *engine,
  * actually occurs in the default signal handler.
  *
  * Returns: whether the plugin has been successfully unloaded.
- * Virtual: unload_plugin
  */
 gboolean
 peas_engine_unload_plugin (PeasEngine     *engine,
@@ -1006,7 +1004,7 @@ peas_engine_provides_extension (PeasEngine     *engine,
 }
 
 /**
- * peas_engine_create_extensionv:
+ * peas_engine_create_extensionv: (rename-to peas_engine_create_extension)
  * @engine: A #PeasEngine.
  * @info: A loaded #PeasPluginInfo.
  * @extension_type: The implemented extension #GType.
@@ -1022,8 +1020,6 @@ peas_engine_provides_extension (PeasEngine     *engine,
  *
  * Returns: (transfer full): a new instance of #PeasExtension wrapping
  * the @extension_type instance, or %NULL.
- *
- * Rename to: peas_engine_create_extension
  */
 PeasExtension *
 peas_engine_create_extensionv (PeasEngine     *engine,
