@@ -63,6 +63,7 @@ test_engine_new (PeasEngine *engine)
 {
   PeasEngine *new_engine;
 
+  /* Only one testing engine can be alive */
   new_engine = peas_engine_new ();
 
   g_assert (engine != NULL);
@@ -98,7 +99,12 @@ test_engine_get_default (void)
 
   g_assert (peas_engine_get_default () == peas_engine_get_default ());
 
-  g_object_unref (peas_engine_get_default ());
+  /* Only has a single ref */
+  test_engine = peas_engine_get_default ();
+  g_object_add_weak_pointer (G_OBJECT (test_engine),
+                             (gpointer *) &test_engine);
+  g_object_unref (test_engine);
+  g_assert (test_engine == NULL);
 
 
   /* Check that the default engine is the newly created engine
@@ -427,25 +433,31 @@ test_engine_nonexistent_search_path (PeasEngine *engine)
   peas_engine_add_search_path (engine, "/nowhere", NULL);
 }
 
-
+#if GLIB_CHECK_VERSION (2, 38, 0)
 static void
 test_engine_shutdown (void)
 {
-  /* Should be able to shutdown multiple times */
-  peas_engine_shutdown ();
-  peas_engine_shutdown ();
-
-  /* Cannot create an engine because libpeas has been shutdown */
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      peas_engine_new ();
-      exit (0);
-    }
+  g_test_trap_subprocess ("/engine/shutdown/subprocess", 0, 0);
   g_test_trap_assert_failed ();
   g_test_trap_assert_stderr ("*libpeas cannot create a plugin "
                               "engine as it has been shutdown*");
 }
 
+static void
+test_engine_shutdown_subprocess (PeasEngine *engine)
+{
+    testing_engine_free (engine);
+
+    /* Should be able to shutdown multiple times */
+    peas_engine_shutdown ();
+    peas_engine_shutdown ();
+
+    /* Cannot create an engine because libpeas has been shutdown */
+    engine = peas_engine_new ();
+    g_assert (engine == NULL);
+}
+#endif
+
 int
 main (int    argc,
       char **argv)
@@ -484,8 +496,10 @@ main (int    argc,
 
   TEST ("nonexistent-search-path", nonexistent_search_path);
 
-  /* MUST be last */
+#if GLIB_CHECK_VERSION (2, 38, 0)
   TEST_FUNC ("shutdown", shutdown);
+  TEST ("shutdown/subprocess", shutdown_subprocess);
+#endif
 
 #undef TEST
 
